@@ -17,6 +17,7 @@ from numbers import Number
 from copy import deepcopy
 import traceback as tb_module
 import io
+import warnings
 
 import numpy as np
 
@@ -34,7 +35,6 @@ from qcodes.utils.helpers import NumpyJSONEncoder
 from qcodes.utils.deprecate import deprecate
 import qcodes.utils.validators as vals
 from qcodes.utils.delaykeyboardinterrupt import DelayedKeyboardInterrupt
-import qcodes.config
 
 log = logging.getLogger(__name__)
 
@@ -79,7 +79,8 @@ class DataSaver:
 
     def __init__(self, dataset: DataSet,
                  write_period: float,
-                 interdeps: InterDependencies_) -> None:
+                 interdeps: InterDependencies_,
+                 write_in_background: bool) -> None:
         self._dataset = dataset
         if DataSaver.default_callback is not None \
                 and 'run_tables_subscription_callback' \
@@ -98,7 +99,7 @@ class DataSaver:
                                     callback_kwargs={'run_id':
                                                      self._dataset.run_id,
                                                      'snapshot': snapshot})
-        default_subscribers = qcodes.config.subscription.default_subscribers
+        default_subscribers = qc.config.subscription.default_subscribers
         for subscriber in default_subscribers:
             self._dataset.subscribe_from_config(subscriber)
 
@@ -110,6 +111,8 @@ class DataSaver:
         self._known_dependencies: Dict[str, List[str]] = {}
         self.parent_datasets: List[DataSet] = []
 
+        self._write_in_background = write_in_background
+
         for link in self._dataset.parent_dataset_links:
             self.parent_datasets.append(load_by_guid(link.tail))
 
@@ -532,11 +535,17 @@ class DataSaver:
         log.debug('Flushing to database')
         if self._results != []:
             try:
-                write_point = self._dataset.add_results(self._results)
-                log.debug(f'Successfully wrote from index {write_point}')
+                self._dataset.add_results(self._results)
+                if self._write_in_background:
+                    log.debug(f"Succesfully enqueued result for write thread")
+                else:
+                    log.debug(f'Successfully wrote result to disk')
                 self._results = []
             except Exception as e:
-                log.warning(f'Could not commit to database; {e}')
+                if self._write_in_background:
+                    log.warning(f"Could not enqueue result; {e}")
+                else:
+                    log.warning(f'Could not commit to database; {e}')
         else:
             log.debug('No results to flush')
 
@@ -575,7 +584,12 @@ class Runner:
                                         Union[MutableSequence,
                                               MutableMapping]]] = None,
             parent_datasets: List[Dict] = [],
-            extra_log_info: str = '') -> None:
+            extra_log_info: str = '',
+            write_in_background: bool = False) -> None:
+
+        if write_in_background and (write_period is not None):
+            warnings.warn(f"The specified write period of {write_period} s "
+                          "will be ignored, since write_in_background==True")
 
         self.enteractions = enteractions
         self.exitactions = exitactions
@@ -593,9 +607,12 @@ class Runner:
         # be read from some config file
         self.write_period = float(write_period) \
             if write_period is not None else 5.0
+        if write_in_background:
+            self.write_period = 0.0
         self.name = name if name else 'results'
         self._parent_datasets = parent_datasets
         self._extra_log_info = extra_log_info
+        self._write_in_background = write_in_background
 
     def __enter__(self) -> DataSaver:
         # TODO: should user actions really precede the dataset?
@@ -629,7 +646,7 @@ class Runner:
         links = [Link(head=self.ds.guid, **pdict)
                  for pdict in self._parent_datasets]
         self.ds.parent_dataset_links = links
-        self.ds.mark_started()
+        self.ds.mark_started(start_bg_writer=self._write_in_background)
 
         # register all subscribers
         for (callble, state) in self.subscribers:
@@ -643,10 +660,13 @@ class Runner:
               f' {self._extra_log_info}')
         log.info(f'Starting measurement with guid: {self.ds.guid}.'
                  f' {self._extra_log_info}')
+        log.info(f'Using background writing: {self._write_in_background}')
 
-        self.datasaver = DataSaver(dataset=self.ds,
-                                   write_period=self.write_period,
-                                   interdeps=self._interdependencies)
+        self.datasaver = DataSaver(
+                            dataset=self.ds,
+                            write_period=self.write_period,
+                            interdeps=self._interdependencies,
+                            write_in_background=self._write_in_background)
 
         return self.datasaver
 
@@ -675,6 +695,8 @@ class Runner:
 
             # and finally mark the dataset as closed, thus
             # finishing the measurement
+            # Note that the completion of a dataset entails waiting for the
+            # write thread to terminate (iff the write thread has been started)
             self.ds.mark_completed()
             log.info(f'Finished measurement with guid: {self.ds.guid}. '
                      f'{self._extra_log_info}')
@@ -686,7 +708,8 @@ T = TypeVar('T', bound='Measurement')
 
 class Measurement:
     """
-    Measurement procedure container
+    Measurement procedure container. Note that multiple measurement
+    instances cannot be nested.
 
     Args:
         exp: Specify the experiment to use. If not given
@@ -1193,9 +1216,15 @@ class Measurement:
 
         return self
 
-    def run(self) -> Runner:
+    def run(self, write_in_background: bool = False) -> Runner:
         """
         Returns the context manager for the experimental run
+
+        Args:
+            write_in_background: if True, results that will be added
+                within the context manager with ``DataSaver.add_result``
+                will be stored in background, without blocking the
+                main thread that is executing the context manager.
         """
         return Runner(self.enteractions, self.exitactions,
                       self.experiment, station=self.station,
@@ -1204,4 +1233,5 @@ class Measurement:
                       name=self.name,
                       subscribers=self.subscribers,
                       parent_datasets=self._parent_datasets,
-                      extra_log_info=self._extra_log_info)
+                      extra_log_info=self._extra_log_info,
+                      write_in_background=write_in_background)
